@@ -173,7 +173,7 @@ def init():
                 val=len(res)
                 print(val)
                 # data=str(res)
-                print("inside except")
+                # print("inside except")
                 # index=data.index("Repository")
                 # index1 = data.index(":",index+1)
                 # index2 = data.index("\n",index1+1)
@@ -185,6 +185,7 @@ def init():
                     res=origin.pull()
                     print("pull succeessfull")
                     time.sleep(10)
+                    val=0
                 else:
                     print("no files to pull")
                     time.sleep(10)
@@ -204,7 +205,7 @@ def init():
                 val=len(res)
                 print(val)
                 # data=str(res)
-                print("inside except")
+                # print("inside except")
                 # index=data.index("Repository")
                 # index1 = data.index(":",index+1)
                 # index2 = data.index("\n",index1+1)
@@ -216,6 +217,7 @@ def init():
                     res=origin.pull()
                     print("pull succeessfull")
                     time.sleep(10)
+                    val=0
                 else:
                     print("no files to pull")
                     time.sleep(10)
